@@ -7,7 +7,10 @@ use std::{
     fs::{self, create_dir, read_dir, read_to_string},
 };
 
-use crate::{model::Model, utils::fs::create_file};
+use crate::{
+    model::Model,
+    utils::{fs::create_file, swc},
+};
 
 #[derive(Clone, Debug, PartialEq)]
 pub struct Version(u8, u8, u8);
@@ -144,6 +147,12 @@ impl Project {
             create_file(&path, styles)?;
         }
 
+        // Compile scripts
+        if let Ok(js) = swc::compile_ts("template/scripts/app.ts") {
+            let path = format!("{}/public/scripts/app.js", self.name);
+            create_file(&path, js)?;
+        }
+
         // Misc
         create_file(
             &format!("{}/.env", self.name),
